PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Pin.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Typedefs
Pin.hpp File Reference
`#include "Py.hpp"`
`#include "Component.hpp"`
`#include "Color.hpp"`
`#include <vector>`

Go to the source code of this file.

## Data Structures
class | Pin

## Typedefs
using | PinCompound = std::vector<Pin *>

## Typedef Documentation

## ◆ PinCompound

using PinCompound = std::vector<Pin *>